pub enum Minifier {
PNG,
JSON,
TOML,
NBT,
OGG,
JAR,
Hash,
Slash,
UnixLine,
}Expand description
A type to determine a minifying method and minimum compress size for file data.
Variants
PNG
A PNG minifier using oxipng.
JSON
A JSON minifier using serde_json.
TOML
A TOML minifier using toml.
NBT
A customized NBT minifier
OGG
An OGG minifier using optivorbis.
JAR
A simple repacker for embedded JAR archives
Hash
A minifier that removes hash (#) comment lines (and empty lines)
Slash
A minifier that removes double-slash (//) comment lines (and empty lines)
UnixLine
A simple Unix line checker
Implementations
Sourceimpl Minifier
impl Minifier
Sourcepub fn by_extension(ftype: &str) -> Option<Self>
pub fn by_extension(ftype: &str) -> Option<Self>
Return a Minifier based on file extension.
Sourcepub const fn by_file_format(f: KnownFmt) -> Option<Self>
pub const fn by_file_format(f: KnownFmt) -> Option<Self>
Return a Minifier based on known (by this library) file format.
Sourcepub fn minify(
&self,
cfgmap: &ConfigMap,
v: &[u8],
vout: &mut Vec<u8>,
) -> Result<()>
pub fn minify( &self, cfgmap: &ConfigMap, v: &[u8], vout: &mut Vec<u8>, ) -> Result<()>
Minifies file data and writes the result in provided vec.
Errors
Returns an error if minifying fails, depending on file type
Sourcepub const fn compress_min(&self) -> u16
pub const fn compress_min(&self) -> u16
Define a minimal size for file compression. Files with lower sizes will be stored as-is.